Module logging

Module logging 

Functions

prune_old_logs
Delete rotated log files older than keep_days days in the same directory as the log file. Files are matched by the log file name prefix (e.g. “proxy.log”). This prevents unbounded accumulation of daily-rotated log files.
setup
Initialise logging: JSON lines to file + human-readable to stderr.