setup

Function setup 

pub fn setup(log_file: &Path, level: &str) -> Result<WorkerGuard>
Initialise logging: JSON lines to file + human-readable to stderr.

Returns a WorkerGuard that must be kept alive for the duration of the process — dropping it flushes and closes the log file writer.